@@ -23,14 +23,7 @@
 #include "config.h"
 #endif
 
-#include <gtk/gtklabel.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkaccessible.h>
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkaboutdialog.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <libgnomeui/gnome-help.h>
 #include <panel-applet.h>
@@ -116,7 +109,6 @@ static void     cpufreq_applet_size_request      (GtkWidget          *widget,
 						  GtkRequisition     *requisition);
 static void     cpufreq_applet_change_orient     (PanelApplet        *pa,
                                                   PanelAppletOrient   orient);
-
 static gboolean cpufreq_applet_factory           (CPUFreqApplet      *applet,
                                                   const gchar        *iid,
                                                   gpointer            gdata);
@@ -193,10 +185,10 @@ cpufreq_applet_init (CPUFreqApplet *applet)
         applet->icon = gtk_image_new ();
         applet->box = NULL;
 
-	applet->need_refresh = TRUE;
-
 	applet->show_mode = CPUFREQ_MODE_BOTH;
 	applet->show_text_mode = CPUFREQ_MODE_TEXT_FREQUENCY_UNIT;
+	
+	applet->need_refresh = TRUE;
 
         panel_applet_set_flags (PANEL_APPLET (applet), PANEL_APPLET_EXPAND_MINOR);
 	panel_applet_set_background_widget (PANEL_APPLET (applet), GTK_WIDGET (applet));
@@ -386,28 +378,28 @@ cpufreq_applet_size_request (GtkWidget *widget, GtkRequisition *requisition)
 	gint           width;
 
 	applet = CPUFREQ_APPLET (widget);
-	
+
 	GTK_WIDGET_CLASS (cpufreq_applet_parent_class)->size_request (widget, requisition);
 
 	if (applet->orient == PANEL_APPLET_ORIENT_LEFT ||
 	    applet->orient == PANEL_APPLET_ORIENT_RIGHT)
 		return;
-	
+
 	if (applet->show_freq) {
 		labels_width += cpufreq_applet_get_max_label_width (applet) + 2;
-        }
+	}
 
-        if (applet->show_perc) {
+	if (applet->show_perc) {
 		labels_width += cpufreq_applet_get_max_perc_width (applet);
-        }
+	}
 
-        if (applet->show_unit) {
+	if (applet->show_unit) {
 		labels_width += cpufreq_applet_get_max_unit_width (applet);
-        }
+	}
 
-        if (applet->show_icon) {
+	if (applet->show_icon) {
 		GtkRequisition req;
-		
+
 		gtk_widget_size_request (applet->icon, &req);
 		width = GTK_IS_HBOX (applet->box) ?
 			labels_width + req.width + 2 :
@@ -701,7 +693,7 @@ cpufreq_applet_update_visibility (CPUFreqApplet *applet)
 		applet->show_text_mode = show_text_mode;
 		need_update = TRUE;
 	}
-        
+	    
         if (show_freq != applet->show_freq) {
                 applet->show_freq = show_freq;
                 changed = TRUE;
@@ -747,12 +739,12 @@ cpufreq_applet_update_visibility (CPUFreqApplet *applet)
 static void
 cpufreq_applet_update (CPUFreqApplet *applet, CPUFreqMonitor *monitor)
 {
-        gchar          *text_tip, *text_mode = NULL;
-        gchar          *freq_label, *unit_label;
-        gint            freq;
-        gint            perc;
-        guint           cpu;
-        gchar          *governor;
+        gchar       *text_tip, *text_mode = NULL;
+        gchar       *freq_label, *unit_label;
+        gint         freq;
+        gint         perc;
+        guint        cpu;
+        const gchar *governor;
 
         cpu = cpufreq_monitor_get_cpu (monitor);
         freq = cpufreq_monitor_get_frequency (monitor);
@@ -803,6 +795,7 @@ cpufreq_applet_update (CPUFreqApplet *applet, CPUFreqMonitor *monitor)
 			g_strdup_printf ("%s", text_mode) :
 			g_strdup_printf ("CPU %u - %s", cpu, text_mode);
 		g_free (text_mode);
+           
 		gtk_widget_set_tooltip_text (GTK_WIDGET (applet), text_tip);
 		g_free (text_tip);
 	}
@@ -823,7 +816,7 @@ cpufreq_applet_get_widget_size (CPUFreqApplet *applet,
 
         if (!GTK_WIDGET_VISIBLE (widget))
                 return 0;
-        
+	
         gtk_widget_size_request (widget, &req);
         
         switch (applet->orient) {
@@ -845,12 +838,12 @@ cpufreq_applet_get_widget_size (CPUFreqApplet *applet,
 static void
 cpufreq_applet_refresh (CPUFreqApplet *applet)
 {
-        gint       total_size = 0;
-        gint       panel_size, label_size;
-        gint       unit_label_size, pixmap_size;
-        gint       size_step = 12;
-	gboolean   horizontal;
-        gboolean   do_unref = FALSE;
+        gint      total_size = 0;
+        gint      panel_size, label_size;
+        gint      unit_label_size, pixmap_size;
+        gint      size_step = 12;
+	gboolean  horizontal;
+        gboolean  do_unref = FALSE;
 
         panel_size = applet->size - 1; /* 1 pixel margin */
 
@@ -874,7 +867,10 @@ cpufreq_applet_refresh (CPUFreqApplet *applet)
         total_size += pixmap_size;
 
         if (applet->box) {
-	        if (applet->labels_box) {
+                do_unref = TRUE;
+                g_object_ref (applet->icon);
+                gtk_container_remove (GTK_CONTAINER (applet->box), applet->icon);
+		if (applet->labels_box) {
                         g_object_ref (applet->label);
                         gtk_container_remove (GTK_CONTAINER (applet->labels_box), applet->label);
                         g_object_ref (applet->unit_label);
@@ -940,9 +936,9 @@ cpufreq_applet_prefs_show_mode_changed (CPUFreqPrefs  *prefs,
 static void
 cpufreq_applet_setup (CPUFreqApplet *applet)
 {
-        BonoboUIComponent *popup_component;
-        AtkObject         *atk_obj;
-        gchar             *prefs_key;
+        BonoboUIComponent  *popup_component;
+        AtkObject          *atk_obj;
+        gchar              *prefs_key;
 
 	g_set_application_name  (_("CPU Frequency Scaling Monitor"));
 
@@ -971,7 +967,7 @@ cpufreq_applet_setup (CPUFreqApplet *applet)
                           "notify::show-text-mode",
                           G_CALLBACK (cpufreq_applet_prefs_show_mode_changed),
                           (gpointer) applet);
-        
+
         /* Monitor */
         applet->monitor = cpufreq_monitor_factory_create_monitor (
                 cpufreq_prefs_get_cpu (applet->prefs));
