@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.107 2006/05/29 23:33:11 philipl Exp $ */
+/* $Id: gweather-applet.c 11123 2008-11-11 08:00:38Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -22,12 +22,21 @@
 #include <gnome.h>
 #include <panel-applet.h>
 #include <libgnomeui/gnome-window-icon.h>
+#include <panel-applet-gconf.h>
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
 #include <libnotify/notification.h>
 #endif
 
+#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
+
+#ifdef HAVE_NETWORKMANAGER
+#include <dbus/dbus-glib.h>
+#include <dbus/dbus-glib-lowlevel.h>
+#include <NetworkManager/NetworkManager.h>
+#endif
+
 #include "gweather.h"
 #include "gweather-about.h"
 #include "gweather-pref.h"
@@ -77,7 +86,6 @@ static void pref_cb (BonoboUIComponent *uic,
 	gw_applet->pref_dialog = gweather_pref_new(gw_applet);
 	g_object_add_weak_pointer(G_OBJECT(gw_applet->pref_dialog),
 				  (gpointer *)&(gw_applet->pref_dialog));
-	/* XXX: This should not be necessary */
 	gtk_widget_show_all (gw_applet->pref_dialog);
    }
 }
@@ -122,6 +130,7 @@ static void place_widgets (GWeatherApplet *gw_applet)
     gboolean horizontal = FALSE;
     int panel_size = gw_applet->size;
     const gchar *temp;   
+    const gchar *icon_name;
 	
     switch (gw_applet->orient) {
 	case PANEL_APPLET_ORIENT_LEFT:
@@ -135,14 +144,10 @@ static void place_widgets (GWeatherApplet *gw_applet)
     }
 
     /* Create the weather icon */
-    weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
-    				 &(gw_applet->applet_pixbuf));     
-    gw_applet->image = gtk_image_new_from_pixbuf (gw_applet->applet_pixbuf);
-    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
-    			       gw_applet->applet_pixbuf);
+    icon_name = weather_info_get_icon_name (gw_applet->gweather_info);
+    gw_applet->image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_BUTTON); 
 
-    /* Check the weather icon sizes to determine box layout */
-    if (gw_applet->applet_pixbuf != NULL) {
+    if (icon_name != NULL) {
         gtk_widget_size_request(gw_applet->image, &req);
         if (horizontal)
             total_size += req.height;
@@ -290,10 +295,12 @@ applet_destroy (GtkWidget *widget, GWeatherApplet *gw_applet)
     weather_info_abort (gw_applet->gweather_info);
 }
 
+#ifdef HAVE_NETWORKMANAGER
+static void setup_network_monitor (GWeatherApplet *gw_applet);
+#endif
+
 void gweather_applet_create (GWeatherApplet *gw_applet)
 {
-    GtkTooltips *tooltips;
-    GtkIconInfo *icon_info;
     AtkObject *atk_obj;
 
     gw_applet->gweather_pref.location = NULL;
@@ -301,21 +308,19 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     gw_applet->gweather_pref.update_enabled = TRUE;
     gw_applet->gweather_pref.detailed = FALSE;
     gw_applet->gweather_pref.radar_enabled = TRUE;
-	gw_applet->gweather_pref.temperature_unit = TEMP_UNIT_INVALID;
-	gw_applet->gweather_pref.speed_unit = SPEED_UNIT_INVALID;
-	gw_applet->gweather_pref.pressure_unit = PRESSURE_UNIT_INVALID;
-	gw_applet->gweather_pref.distance_unit = DISTANCE_UNIT_INVALID;
+    gw_applet->gweather_pref.temperature_unit = TEMP_UNIT_INVALID;
+    gw_applet->gweather_pref.speed_unit = SPEED_UNIT_INVALID;
+    gw_applet->gweather_pref.pressure_unit = PRESSURE_UNIT_INVALID;
+    gw_applet->gweather_pref.distance_unit = DISTANCE_UNIT_INVALID;
     
     panel_applet_set_flags (gw_applet->applet, PANEL_APPLET_EXPAND_MINOR);
 
     panel_applet_set_background_widget(gw_applet->applet,
                                        GTK_WIDGET(gw_applet->applet));
-    
-    icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "stock_weather-storm", 48, 0);
-    if (icon_info) {
-        gnome_window_icon_set_default_from_file (gtk_icon_info_get_filename (icon_info));
-        gtk_icon_info_free (icon_info);
-    }
+
+    g_set_application_name (_("Weather Report"));
+
+    gtk_window_set_default_icon_name ("weather-storm");
 
     gw_applet->container = gtk_alignment_new (0.5, 0.5, 0, 0);
     gtk_container_add (GTK_CONTAINER (gw_applet->applet), gw_applet->container);
@@ -329,11 +334,9 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     g_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
                        GTK_SIGNAL_FUNC(clicked_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "key_press_event",           
-			G_CALLBACK(key_press_cb), gw_applet);                    
+			G_CALLBACK(key_press_cb), gw_applet);
                      
-    tooltips = gtk_tooltips_new();
-
-    gtk_tooltips_set_tip(tooltips, GTK_WIDGET(gw_applet->applet), _("GNOME Weather"), NULL);
+    gtk_widget_set_tooltip_text (GTK_WIDGET(gw_applet->applet), _("GNOME Weather"));
 
     atk_obj = gtk_widget_get_accessible (GTK_WIDGET (gw_applet->applet));
     if (GTK_IS_ACCESSIBLE (atk_obj))
@@ -360,12 +363,12 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 					  "hidden", "1",
 					  NULL);
     }
-
-    gw_applet->tooltips = tooltips;
 	
-    place_widgets(gw_applet);
-  
-	return;
+    place_widgets(gw_applet);        
+
+#ifdef HAVE_NETWORKMANAGER
+    setup_network_monitor (gw_applet);     
+#endif
 }
 
 gint timeout_cb (gpointer data)
@@ -382,12 +385,12 @@ update_finish (WeatherInfo *info, gpointer data)
     static int gw_fault_counter = 0;
 #ifdef HAVE_LIBNOTIFY
     char *message, *detail;
-    GdkPixbuf *pixbuf = NULL;
     GConfClient *conf;
 #endif
     char *s;
     GWeatherApplet *gw_applet = (GWeatherApplet *)data;
     gint nxtSunEvent;
+    const gchar *icon_name;
 
     /* Update timer */
     if (gw_applet->timeout_tag > 0)
@@ -410,18 +413,16 @@ update_finish (WeatherInfo *info, gpointer data)
 	     (gw_fault_counter >= MAX_CONSECUTIVE_FAULTS))
     {
 	    gw_fault_counter = 0;
-	    weather_info_get_pixbuf_mini (gw_applet->gweather_info, 
-	    				 &(gw_applet->applet_pixbuf));
-	    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
-	    			       gw_applet->applet_pixbuf);
+            icon_name = weather_info_get_icon_name (gw_applet->gweather_info);
+            gtk_image_set_from_icon_name (GTK_IMAGE(gw_applet->image), 
+                                          icon_name, GTK_ICON_SIZE_BUTTON);
 	      
 	    gtk_label_set_text (GTK_LABEL (gw_applet->label), 
 	        		weather_info_get_temp_summary(
 					gw_applet->gweather_info));
 	    
 	    s = weather_info_get_weather_summary (gw_applet->gweather_info);
-	    gtk_tooltips_set_tip (gw_applet->tooltips, GTK_WIDGET (
-				    gw_applet->applet), s, NULL);
+	    gtk_widget_set_tooltip_text (GTK_WIDGET (gw_applet->applet), s);
 	    g_free (s);
 
 	    /* Update dialog -- if one is present */
@@ -429,6 +430,9 @@ update_finish (WeatherInfo *info, gpointer data)
 	    	gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
 	    }
 
+	    /* update applet */
+	    place_widgets(gw_applet);
+
 #ifdef HAVE_LIBNOTIFY
 	    if (panel_applet_gconf_get_bool (gw_applet->applet,
 				    "show_notifications", NULL))
@@ -442,6 +446,7 @@ update_finish (WeatherInfo *info, gpointer data)
 		    if (notify_is_initted ())
 		    {
 			 GError *error = NULL;
+                         const char *icon;
 			 
 	           	 /* Show notification */
 	           	 message = g_strdup_printf ("%s: %s",
@@ -452,15 +457,14 @@ update_finish (WeatherInfo *info, gpointer data)
 					 weather_info_get_location_name (info),
 					 weather_info_get_sky (info),
 					 weather_info_get_temp_summary (info));
+
+			 icon = weather_info_get_icon_name (gw_applet->gweather_info);
+			 if (icon == NULL)
+				 icon = "stock-unknown";
 	           	 
-			 n = notify_notification_new (message, detail, NULL,
+			 n = notify_notification_new (message, detail, icon,
 					 gw_applet->container);
 	
-			 /* set the pixbuf */
-	           	 weather_info_get_pixbuf (gw_applet->gweather_info,
-					 &pixbuf);
-	 	   	 if (pixbuf)
-	 	   	    notify_notification_set_icon_from_pixbuf (n, pixbuf);
 		   	 notify_notification_show (n, &error);
 			 if (error)
 			 {
@@ -494,14 +498,12 @@ gint suncalc_timeout_cb (gpointer data)
 void gweather_update (GWeatherApplet *gw_applet)
 {
     WeatherPrefs prefs;
+    const gchar *icon_name;
 
-    weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
-    				 &(gw_applet->applet_pixbuf));
-
-    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
-    			       gw_applet->applet_pixbuf);
-    gtk_tooltips_set_tip(gw_applet->tooltips, GTK_WIDGET(gw_applet->applet), 
-    			 _("Updating..."), NULL);
+    icon_name = weather_info_get_icon_name(gw_applet->gweather_info);
+    gtk_image_set_from_icon_name (GTK_IMAGE (gw_applet->image), 
+    			          icon_name, GTK_ICON_SIZE_BUTTON); 
+    gtk_widget_set_tooltip_text (GTK_WIDGET(gw_applet->applet),  _("Updating..."));
 
     /* Set preferred forecast type */
     prefs.type = gw_applet->gweather_pref.detailed ? FORECAST_ZONE : FORECAST_STATE;
@@ -531,3 +533,89 @@ void gweather_update (GWeatherApplet *gw_applet)
 						    update_finish, gw_applet);
     }
 }
+
+#ifdef HAVE_NETWORKMANAGER
+static void
+state_notify (DBusPendingCall *pending, gpointer data)
+{
+	GWeatherApplet *gw_applet = data;
+
+        DBusMessage *msg = dbus_pending_call_steal_reply (pending);
+
+        if (!msg)
+                return;
+
+        if (dbus_message_get_type (msg) == DBUS_MESSAGE_TYPE_METHOD_RETURN) {
+                dbus_uint32_t result;
+
+                if (dbus_message_get_args (msg, NULL,
+                                           DBUS_TYPE_UINT32, &result,
+                                           DBUS_TYPE_INVALID)) {
+                        if (result == NM_STATE_CONNECTED) {
+				gweather_update (gw_applet);
+                        }
+                }
+        }
+
+        dbus_message_unref (msg);
+}
+
+static void
+check_network (DBusConnection *connection, gpointer user_data)
+{
+        DBusMessage *message;
+        DBusPendingCall *reply;
+
+        message = dbus_message_new_method_call (NM_DBUS_SERVICE,
+                                                NM_DBUS_PATH,
+                                                NM_DBUS_INTERFACE,
+                                                "state");
+        if (dbus_connection_send_with_reply (connection, message, &reply, -1)) {
+                dbus_pending_call_set_notify (reply, state_notify, user_data, NULL);
+                dbus_pending_call_unref (reply);
+        }
+
+        dbus_message_unref (message);
+}
+
+static DBusHandlerResult
+filter_func (DBusConnection *connection, DBusMessage *message, void *user_data)
+{
+    if (dbus_message_is_signal (message, 
+				NM_DBUS_INTERFACE, 
+				"StateChanged")) {
+	check_network (connection, user_data);
+
+        return DBUS_HANDLER_RESULT_HANDLED;
+    }
+
+    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+}
+
+static void
+setup_network_monitor (GWeatherApplet *gw_applet)
+{
+    GError *error;
+    static DBusGConnection *bus = NULL;
+    DBusConnection *dbus;
+
+    if (bus == NULL) {
+        error = NULL;
+        bus = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
+        if (bus == NULL) {
+            g_warning ("Couldn't connect to system bus: %s",
+                       error->message);
+            g_error_free (error);
+
+            return;
+        }
+
+        dbus = dbus_g_connection_get_connection (bus);	
+        dbus_connection_add_filter (dbus, filter_func, gw_applet, NULL);
+        dbus_bus_add_match (dbus,
+                            "type='signal',"
+                            "interface='" NM_DBUS_INTERFACE_DEVICE "'",
+                            NULL);
+    }
+}	
+#endif /* HAVE_NETWORKMANAGER */
